Attribute VB_Name = "TextFileHandling"
' Modul         : TextFileHandling
' System        : VB 6.0 SP6
' Copyright (C) : E+A Forschungsinstitut Elektromaschinen GmbH, CH-4313 Mhlin
'
' Beschreibung  : Verwaltung von Text-Files, Ini-Files, Log-Files
'
' Prozeduren    : sub  TextFileAddLine    Zeile an Datei anhngen (Datei wird erstellt wenn nicht vorhanden)
'                 sub  TextFileCreate     File erstellen (vorhandenes File wird gelscht)
'                 func TextFileReadOpen   File zum lesen ffnen, als ASCII-File
'                 func TextFileReadLine   Eine Zeile aus dem File lesen, Rckgabe des Vorgabewertes wenn nicht gefunden
'
' Prozeduren    : sub  IniFileRead        Ini File in Array einlesen, Rckgabe des Vorgabewertes wenn nicht gefunden
'                 sub  IniFileWrite       Ini File aus Array erstellen (vorhandenes File wird gelscht)
'                 sub  IniDataRead        Wert aus IniFile auslesen  (Angabe von FileName, Gruppe, Schlssel, Wert), Rckgabe des Vorgabewertes wenn nicht gefunden
'                 sub  IniDataWrite       Wert in  IniFile schreiben (Angabe von FileName, Gruppe, Schlssel, Wert)
'
' Prozeduren    : sub  WriteLogFile       Log File erstellen, Zeilen hinzufgen (App.Name.log)
'
' nderungen    :
' 03.01.2002/be : Datum bei Logfile Eintrag angepasst
' 05.06.2001/be : Vorgabewert zurckgeben wenn nicht gefunden beim lesen
' 26.04.2001/be : Hinzufgen Proz "WriteLogFile"
' 24.04.2001/Be : nderung in eine Klasse,
'                 Zusammenfassung von modFileTextIO.bas und modFileIniHandling.bas
' 02.03.2000/Be : Programmier Beginn
'

Option Explicit

Public Type IniZeile
  IniZeileText    As String
  IniZeileKey     As String
  IniZeileData    As String
  IniZeileGruppe  As Long
  IniZeileCount   As Long
End Type

Private Declare Function GetPrivateProfileString Lib "kernel32" Alias "GetPrivateProfileStringA" (ByVal lpApplicationname As String, ByVal lpKeyName As String, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long
Private Declare Function WritePrivateProfileString Lib "kernel32" Alias "WritePrivateProfileStringA" (ByVal lpApplicationname As String, ByVal lpKeyName As Any, ByVal lsString As Any, ByVal lplFilename As String) As Long

'Text-File++++++++++++++++++++++++++++++
' Text-File Handling
' 24.4.2001/be
Public Sub TextFileAddLine(TextFileName As String, TextLine As String)
  Dim objFileObject   As Object
  Dim objWriteObject  As Object
  Dim strEOL          As String
  strEOL = Chr(13) + Chr(10)
  Set objFileObject = CreateObject("Scripting.FileSystemObject")
  Set objWriteObject = objFileObject.OpenTextFile(TextFileName, 8, True, 0)    'ffnen als ForAppending, Datei erstellen wenn nicht vorhanden, als ASCII-File
  objWriteObject.Write TextLine + strEOL
  objWriteObject.Close
End Sub

Public Sub TextFileCreate(TextFileName As String)
  Dim objFileObject As Object
  Set objFileObject = CreateObject("Scripting.FileSystemObject")    'Objekt deklarieren
  objFileObject.CreateTextFile TextFileName                         'Erstellen einer Datei
End Sub

Public Function TextFileReadOpen(TextFileName As String) As Object
  Dim objFileObject  As Object
  Set objFileObject = CreateObject("Scripting.FileSystemObject")
  Set TextFileReadOpen = objFileObject.OpenTextFile(TextFileName, 1, False, 0)    'ffnen als ForReading, Datei nicht erstellen wenn nicht vorhanden, als ASCII-File
End Function

Public Function TextFileReadLine(objReadObject As Object, Optional Vorgabe As String) As String
  On Error GoTo TextFileReadLine_Error
  TextFileReadLine = objReadObject.ReadLine
  Exit Function
TextFileReadLine_Error:
  TextFileReadLine = Vorgabe
  Resume Next
End Function

Public Sub TextFileReadClose(objReadObject As Object)
  objReadObject.Close
End Sub
'Text-File------------------------------


'Ini-File++++++++++++++++++++++++++++++
' Ini-File Handling
' 24.4.2001/be
Public Sub IniFileRead(FileName As String, IniZeilen() As IniZeile, IniZeilenAnzahl As Long, Optional Vorgabe As String)
  Dim objReadObject       As Object
  Dim strText             As String
  Dim strKey              As String
  Dim strData             As String
  Dim strSplit()          As String
  Dim lngIniGruppenAnzahl As Long
  Set objReadObject = TextFileReadOpen(FileName)
  Do
    strText = TextFileReadLine(objReadObject, Vorgabe)
    If strText = Vorgabe Then Exit Do
    If Trim(strText) <> "" Then                           'leere Zeilen werden nicht bernommen
      If Left(strText, 1) = "[" Then
        lngIniGruppenAnzahl = lngIniGruppenAnzahl + 1
        strKey = ""                                       'wenn Gruppe Key lschen
        strData = ""                                      'wenn Gruppe Data lschen
      Else
        strSplit = Split(Trim(strText), "=")
        strKey = Trim(strSplit(LBound(strSplit)))         'wenn keine Gruppe Key herausfiltern
        strData = Trim(strSplit(UBound(strSplit)))        'wenn keine Gruppe Data herausfiltern
      End If
      IniZeilenAnzahl = IniZeilenAnzahl + 1
      With IniZeilen(IniZeilenAnzahl)
        .IniZeileText = strText
        .IniZeileKey = strKey
        .IniZeileData = strData
        .IniZeileGruppe = lngIniGruppenAnzahl
      End With
    End If
  Loop
  Call TextFileReadClose(objReadObject)
End Sub

Public Sub IniFileWrite(FileName As String, IniZeilen() As IniZeile, IniZeilenAnzahl As Long)
  Dim lngCount As Long
  Call TextFileCreate(FileName)
  For lngCount = 1 To IniZeilenAnzahl
    Call TextFileAddLine(FileName, IniZeilen(lngCount).IniZeileText)
  Next
End Sub

Public Function IniDataRead(FileName As String, IniGroup As String, IniKey As String, Optional Vorgabe As String) As String
  Dim lngErgebnis As Long
  Dim Text        As String
  Text = Space(200)
  lngErgebnis = GetPrivateProfileString(IniGroup, IniKey, FileName, Text, Len(Text), FileName)
  If lngErgebnis = 0 Then
    IniDataRead = Vorgabe                                   'Rckgabe des Vorgabewertes wenn nicht vorhanden
  Else
    Text = Trim(Text)
    IniDataRead = Left(Text, InStr(Text, Chr(0)) - 1)       'Entfernen von chr(0) am Stringende
    If IniDataRead = FileName Then IniDataRead = Vorgabe    'wenn IniData=Filename ist der Schlssel nicht vorhanden
  End If
End Function

Public Sub IniDataWrite(FileName As String, IniGroup As String, IniKey As String, IniData As String)
  Dim Ergebnis As Long
  Ergebnis = WritePrivateProfileString(IniGroup, IniKey, IniData, FileName)
End Sub
'Ini-File------------------------------


'LogFile++++++++++++++++++++++++++++++
' Log File schreiben
' 06.03.2001 Rtr
Public Sub WriteLogFile(LogFile As String, LogText As String, AppClient As Object)
  Dim LogZeile  As String
  On Error Resume Next
  LogZeile = Left(Date & Space(10), 10) & ", "
  LogZeile = LogZeile & Left(Time & Space(10), 9) & "- "
  LogZeile = LogZeile & Left(Environ("UserName") & Space(10), 4) & "- "
  LogZeile = LogZeile & Left(CStr(AppClient.Major) & "." & CStr(AppClient.Minor) & "." & CStr(AppClient.Revision) & Space(10), 10) & "-  "
  LogZeile = LogZeile & LogText
  Call TextFileAddLine(LogFile, LogZeile)
End Sub
'LogFile------------------------------

